@@ -29,17 +29,15 @@ def get_current_version():
         version_maybe = pyproject.get("tool", {}).get("poetry", {}).get("version", "")
         pattern = re.compile(r"([0-9]+\.){2}([0-9]+)")
         m = re.match(pattern, version_maybe)
-        if m:
-            current_version = m.group(0)
-            LOG.info(
-                f"Version file has been read and version is set to {current_version}"
-            )
-            return current_version
-        else:
+        if m is None:
             LOG.error("Could not read version file")
             return None
+
+        current_version = m.group(0)
+        LOG.info(f"Version file has been read and version is set to {current_version}")
+        return current_version
     except Exception as ex:
-        LOG.error("Could not read version file")
+        LOG.error(f"Could not read version file {ex}")
         return None
 
 
